@@ -1,6 +1,7 @@
 import logging
 from abc import ABC
 from abc import abstractmethod
+from typing import ClassVar
 from typing import Dict
 from typing import Optional
 from typing import Tuple
@@ -9,6 +10,12 @@ from datapilot.core.insights.schema import InsightResponse
 
 
 class Insight(ABC):
+    NAME = "Insight"
+    TYPE = "BaseInsight"
+    DESCRIPTION = "Base Insight"
+    FILES_REQUIRED: ClassVar = []
+    ALIAS = "base_insight"
+
     def __init__(self, config: Optional[Dict] = None, *args, **kwargs):
         self.config = config or {}
         self.args = args
